Commonly used types and traits for easy importing.
This module re-exports the most frequently used items from the library, allowing users to import everything they need with a single use statement.
Example
use gotgraph::prelude::*;
let mut graph: VecGraph<i32, &str> = VecGraph::default();
// Now you have access to Graph, GraphUpdate, etc.Re-exports
pub use crate::graph::Graph;pub use crate::graph::GraphRemove;pub use crate::graph::GraphRemoveEdge;pub use crate::graph::GraphUpdate;pub use crate::vec_graph::VecGraph;